/* outline.c -- Test program for multi-level outline (book mark) in a large PDF file (200 pages).
 * Copyright (C) 1998 FastIO Systems, All Rights Reserved.
 * For conditions of use, license, and distribution, see LICENSE.txt or LICENSE.pdf.

NEXTSTEP/OPENSTEP
cc -Wall -o outline outline.c -I/usr/local/include -lcpdf

BSDI/gcc
gcc -Wall -o outline outline.c -L. -lcpdf -lm

SunOS5.4/CC-4.0
cc -o outline outline.c -Xa -L. -lcpdf -lm

1998-11-27  [IO]
*/

#define	NPAGES		200		/* number of pages to generate */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "cpdflib.h"

void show_textStuff(float yloc, int page, int chapter, int section, int subsection)
{
float ybump = 0.3;
char strbuf[128];
    /* == Text examples == */
    /* cpdf_setgrayFill(0.0); */				/* Black */
    cpdf_beginText(0);
    cpdf_setFont("Times-Roman", "MacRomanEncoding", 24.0);
    sprintf(strbuf, "Page: %d", page);
    cpdf_text(1.0, yloc, 0.0, strbuf);	/* cpdf_text() may be repeatedly used */
    yloc -= ybump;
    sprintf(strbuf, "Chapter: %d", chapter);
    cpdf_text(1.0, yloc, 0.0, strbuf);	/* cpdf_text() may be repeatedly used */
    yloc -= ybump;
    sprintf(strbuf, "Section: %d.%d", chapter, section);
    cpdf_text(1.0, yloc, 0.0, strbuf);	/* cpdf_text() may be repeatedly used */
    yloc -= ybump;
    sprintf(strbuf, "Subsection: %d.%d.%d", chapter, section, subsection);
    cpdf_text(1.0, yloc, 0.0, strbuf);	/* cpdf_text() may be repeatedly used */
    yloc -= ybump;

    cpdf_endText();
}

void main(int argc, char *argv[])
{
int page;
int chapter, lastchap=0;
int section, lastsect=0;
int subsection, lastsubsect=0;
int same_sub = 0;
CPDFoutlineEntry *lastChapOL, *lastSectOL, *lastSubsectOL;
float p1=0.0, p2=0.0, p3=0.0, p4=0.0;
char strbuf[128];

    /* == Initialization == */
    /* cpdf_setDocumentLimits(int maxPages, int maxFonts, int maxImages, int maxAnnots, int maxObjects) */
    /* Default limit is 100 pages, so we increase it for our large document */
    cpdf_setDocumentLimits(NPAGES+50, -1, -1, -1, 3000);	/* many pages and 3000 xref objects */
    cpdf_open(0);
    cpdf_enableCompression(YES);		/* use Flate/Zlib compression */
    cpdf_init();

    /* This will have outline (book marks) visible upon document open */
    cpdf_setViewerPreferences(PM_OUTLINES, 0, 0, 0, 0, 0, 0, 0);
    lastChapOL= NULL;

    /* == Generate many pages, and add outline (book mark) entries */
    for(page=1; page <= NPAGES; page++) {
	fprintf(stderr, "Page %d  \r", page);  fflush(stderr);
        cpdf_pageInit(page, PORTRAIT, LETTER, LETTER);	/* create page */
	chapter = (page-1) / 20 + 1;			/* 10 chapters: new chapter every 20 pages */
	section = ((page-1) % 20) / 4 + 1;		/* 5 sections per chapter: new section every 4 pages */
	subsection = ((page-1) % 4) * 2 + 1;		/* 8 sections per section: 2 sections per page */

	/* For this example, we have just minimal page content */
	show_textStuff(9.5, page, chapter, section, subsection);	/* draw text on page */

	p1 = 0.0;		/* left */
	p2 = 11.0*72.0;		/* top */
	p3 = 0.0;		/* zoom (== 0 means keep the current zoom) */

	if(chapter != lastchap) {
	    /* new chapter */
	    sprintf(strbuf, "Chapter %d", chapter);
	    lastChapOL = cpdf_addOutlineEntry(lastChapOL, OL_SAME, OL_OPEN, page, strbuf,
						DEST_XYZ, p1, p2, p3, p4);
	    lastchap = chapter;
	    lastSectOL = lastChapOL;	/* first section of a given chapter is added to chapter outline */
	}
	if(section != lastsect) {
	    /* new section */
	    sprintf(strbuf, "Section %d.%d", chapter, section);
	    if(section == 1) same_sub = OL_SUBENT;	/* sect 1 is a subentry of chapter */
	    else             same_sub = OL_SAME;	/* otherwise, add it to prev section at the same level */
	    lastSectOL = cpdf_addOutlineEntry(lastSectOL, same_sub, OL_CLOSED, page, strbuf,
						DEST_XYZ, p1, p2, p3, p4);
	    lastsect = section;
	    lastSubsectOL = lastSectOL;	/* first subsection of a given section is added to section outline */
	}
	if(subsection != lastsubsect) {
	    /* new subsection */
	    sprintf(strbuf, "Subsection %d.%d.%d", chapter, section, subsection);
	    if(subsection == 1) same_sub = OL_SUBENT;	/* subsect 1 is a subentry of section */
	    else                same_sub = OL_SAME;	/* otherwise, add it to prev subsection at the same level */
	    /* All subsections for this section are closed upon display.  OL_CLOSED does that. */
	    lastSubsectOL = cpdf_addOutlineEntry(lastSubsectOL, same_sub, OL_CLOSED, page, strbuf,
						DEST_XYZ, p1, p2, p3, p4);
	    lastsubsect = subsection;
	}

	/* Another section on the bottom half of page, so we have 2 subsections per page */
	subsection++;
	show_textStuff(4.5, page, chapter, section, subsection);	/* draw text on page */

	/* The second subsection is half way down the page.  So, when the outline for
	   this subsection is clicked and the view is smaller than the page, it will
	   show the lower half of the page by specifying p2 (top) as half way down, and
	   using "/XYZ left top zoom" destination specification.
	   There are many destination options,  For example, the destination can be
	   "/FitR left top right bottom" which will fit this rectangle within the view.
	*/
	p2 = 5.0*72.0;		/* top is now moved down half way */
	if(subsection != lastsubsect) {
	    /* new subsection */
	    sprintf(strbuf, "Subsection %d.%d.%d", chapter, section, subsection);
	    if(subsection == 1) same_sub = OL_SUBENT;	/* subsect 1 is a subentry of section */
	    else                same_sub = OL_SAME;	/* otherwise, add it to prev subsection at the same level */
	    lastSubsectOL = cpdf_addOutlineEntry(lastSubsectOL, same_sub, OL_OPEN, page, strbuf,
						DEST_XYZ, p1, p2, p3, p4);
	    lastsubsect = subsection;
	}

	/* Calling cpdf_finalizePage() will close the page and compress the page
	   content if compression is enabled.  This will conserve memory and will reduce
	   VM swapping if your PDF document has a large number of pages.
	*/
	cpdf_finalizePage(page);

    } /* end of for(page....) */

    /* == generate output and clean up == */
    fprintf(stderr, "\nNow writing PDF...\n");
    cpdf_finalizeAll();			/* PDF file/memstream is actually written here */
    cpdf_savePDFmemoryStreamToFile("outline.pdf");

    /* == Clean up == */
    cpdf_close();			/* shut down */
    cpdf_launchPreview();		/* launch Acrobat/PDF viewer on the output file */
}

